import { useRef, forwardRef } from "react";
import { CSSTransition } from "react-transition-group";
import { dispatch } from "../../../domain/gameStore";
import DelayedButton from "../../util/DelayedButton";
import GameCreationForm from "../../util/GameCreationForm";
import styles from "./HomePage.module.css";
import RecentGames from "./RecentGames";
import useHasSavedInfo from "./useHasSavedInfo";

export const Rejoin = forwardRef((_, ref) => (
  <div className={styles.rejoinSection} ref={ref}>
    <span className={styles.rejoinLabel}>
      Looks like you were in a game before that you didn&apos;t finish!
    </span>
    <DelayedButton
      onEnd={() => dispatch.rejoinGame()}
      countDownFormatter={rem => `Rejoining in ${rem}s...`}
    >
      Rejoin Game?
    </DelayedButton>
  </div>
));

const HomePage = () => {
  const hasSavedInfo = useHasSavedInfo();
  const transitionRef = useRef(null);

  return (
    <div className={styles.page}>
      <CSSTransition
        nodeRef={transitionRef}
        in={hasSavedInfo}
        mountOnEnter
        unmountOnExit
        timeout={500}
        classNames="fade"
      >
        <Rejoin ref={transitionRef} />
      </CSSTransition>
      <div className={styles.row}>
        <GameCreationForm afterCreate={gameId => dispatch.goToLobby(gameId)} />
        <RecentGames />
      </div>
    </div>
  );
};

export default HomePage;
